@@ -3,13 +3,9 @@ extern crate libc;
 use array::Array;
 use defines::{AfError, MatProp, NormType};
 use error::HANDLE_ERROR;
-use util::to_u32;
+use util::{AfArray, MutAfArray, MutDouble, to_u32};
 use self::libc::{uint8_t, c_int, c_uint, c_double};
 
-type MutAfArray = *mut self::libc::c_longlong;
-type MutDouble  = *mut self::libc::c_double;
-type AfArray    = self::libc::c_longlong;
-
 #[allow(dead_code)]
 extern {
     fn af_svd(u: MutAfArray, s: MutAfArray, vt: MutAfArray, input: AfArray) -> c_int;
@@ -403,4 +399,4 @@ pub fn is_lapack_available() -> bool {
         af_is_lapack_available(&mut temp as *mut c_int);
         temp > 0 // Return boolean fla
     }
-}
\ No newline at end of file
+}
